/* Script: LampadasuTavolino.c
 *
 * Composizione della scena e settaggio dei parametri di resa
 * e di texture mapping
 *
 *
 * */

#include "descriptor/descriptor.h"

#define R 0
#define G 1
#define B 2

int main(int argc, char **argv){

	// scene
	ITEM scene;

	// primitives
	ITEM l_plastica;
	ITEM l_valvolaf;
	ITEM l_strutt;
	ITEM t_lastre;
	ITEM t_ornamenti;
	ITEM t_strutt;
	ITEM t_ventose;
	ITEM pavimento;

	// attributes
	ITEM vetroLastra;
	ITEM sostegniTavolino;
	ITEM sostegnieDecorazioni;
	ITEM plasticaVentosa;
	ITEM strutturaLampada;
	ITEM plasticaLampada;
	ITEM moquette;

	// color attributes
	float    bg[3] = { 226, 180, 144 };
	float   Nbg[3] = {   0,   0,   0 };
	float  ambL[3] = {   0,   0,   0 };
	float  keyL[3] = { 255, 255, 255 };
	float fillL[3] = { 255, 255, 255 };
	float backL[3] = { 255, 255, 255 };
	float lampL[3] = { 255, 255, 255 };
	float vlstr[3] = { 199, 248, 234 };
	float Tsust[3] = {  55,  37,  19 };
	float Tstdc[3] = { 125, 110,  68 };
	float plvnt[3] = { 255, 255, 255 };
	float Lstrt[3] = {  94,  62,  45 };
	float Lplst[3] = { 231, 215, 188 };
	float moqtt[3] = { 131,  83,  45 };
	char usage[] = "\n\nUsage: LampadasuTavolino -[d|n]\n\n\t - option 'd' is intended to obtain the 'day view'\n\t - option 'n' is intended to obtain the 'night view'\n\n\n";
	int dayoption = 2;


	if(argc != 2){
		fprintf(stdout, usage, "LampadasuTavolino");
		return(-1);
	}

	if(argv[1][0] == '-'){

		if(argv[1][1] == 'd') dayoption = 1;
		else if(argv[1][1] == 'n') dayoption = 0;
		else{
			fprintf(stdout, usage, "LampadasuTavolino");
			return(-1);
		}

	}
	else{
		fprintf(stdout, usage, "LampadasuTavolino");
		return(-1);
	}

	// background and ambient
	if(dayoption) set_background((bg[R]/255), (bg[G]/255), (bg[B]/255), FALSE);
	else set_background((Nbg[R]/255), (Nbg[G]/255), (Nbg[B]/255), TRUE);
	set_ambient_light((ambL[R]/255), (ambL[G]/255), (ambL[B]/255), 1);

	// lights

	if(dayoption){

		create_warn_light(326.253, -204.458, 167.467, -0.779, 0.488, -0.392,
				 (keyL[R]/255), (keyL[G]/255), (keyL[B]/255), 11, 440,
				  0, 50, 0, 0, 0, 0, 0, "key_Light");

		create_warn_light(70.078, 94.115, 51.442, -0.552, -0.741, -0.382,
				 (fillL[R]/255), (fillL[G]/255), (fillL[B]/255), 1, 195,
				  0, 50, 0, 0, 0, 0, 0, "fill_Light");

		create_warn_light(-136.897, 0.358, 92.351, 0.837, -0.002, -0.545,
				 (backL[R]/255), (backL[G]/255), (backL[B]/255), 6, 185,
				  0, 50, 0, 0, 0, 0, 0, "back_Light");

		create_point_light(0, 0, 2.838, (lampL[R]/255), (lampL[G]/255), (lampL[B]/255),
				   1, 7, "lampadina");

	}
	else create_point_light(0, 0, 2.838, (lampL[R]/255), (lampL[G]/255), (lampL[B]/255),
			        2.75, 7, "lampadina");


	// primitives loading
	l_plastica  = read_obj("LampadaPlastica.obj", "L_plastica");
	l_valvolaf  = read_nurbs("29_valvolafacciata.db");
	l_strutt    = read_obj("LampadaStruttura.obj", "L_strutt");
	t_lastre    = read_obj("Tavolo_lastre.obj", "T_lastre");
	t_ornamenti = read_obj("Tavolo_oro.obj", "T_ornamenti");
	t_strutt    = read_obj("Tavolo_strutt.obj", "T_strutt");
	t_ventose   = read_obj("Tavolo_ventose.obj", "T_ventose");
	pavimento   = read_nurbs("pavimento.db");


	// attributes definitions and linking

	vetroLastra = create_attribute("vetroLastra");
	set_color(vetroLastra, (vlstr[R]/255), (vlstr[G]/255), (vlstr[B]/255), 0.4, 0.5);
	set_reflectivity(vetroLastra, 0.1, 2);
	set_transparency(vetroLastra, 1, 0.8, 2, 1.09);

	sostegniTavolino = create_attribute("sostegniTavolino");
	set_color(sostegniTavolino, (Tsust[R]/255), (Tsust[G]/255), (Tsust[B]/255), 0.2, 1);
	set_reflectivity(sostegniTavolino, 0.5, 2);
	set_transparency(sostegniTavolino, 0, 0, 0, 1.658);

	sostegnieDecorazioni = create_attribute("sostegnieDecorazioni");
	set_color(sostegnieDecorazioni, (Tstdc[R]/255), (Tstdc[G]/255), (Tstdc[B]/255), 0.5, 1);
	set_reflectivity(sostegnieDecorazioni, 0.9, 2);
	set_transparency(sostegnieDecorazioni, 0, 0, 0, 2.42);

	plasticaVentosa = create_attribute("plasticaVentosa");
	set_color(plasticaVentosa, (plvnt[R]/255), (plvnt[G]/255), (plvnt[B]/255), 0, 1);
	set_reflectivity(plasticaVentosa, 0, 2);
	set_transparency(plasticaVentosa, 0.6, 0.1, 2, 1.55);

	strutturaLampada = create_attribute("strutturaLampada");
	set_color(strutturaLampada, (Lstrt[R]/255), (Lstrt[G]/255), (Lstrt[B]/255), 0, 0.8);
	set_reflectivity(strutturaLampada, 0.45, 2);
	set_transparency(strutturaLampada, 0, 0, 0, 1);

	plasticaLampada = create_attribute("plasticaLampada");
	set_color(plasticaLampada, (Lplst[R]/255), (Lplst[G]/255), (Lplst[B]/255), 0.2, 1);
	set_reflectivity(plasticaLampada, 0.325, 2);
	set_transparency(plasticaLampada, 0.8, 0.35, 0, 1);

	moquette = create_attribute("moquette");
	set_color(moquette, (moqtt[R]/255), (moqtt[G]/255), (moqtt[B]/255), 0.1, 1);
	set_reflectivity(moquette, 0.1, 2);
	set_transparency(moquette, 0, 0, 0, 1.658);

	// linking

	set_attribute(l_plastica, plasticaLampada);
	set_attribute(t_lastre, vetroLastra);
	set_attribute(t_ornamenti, sostegnieDecorazioni);
	set_attribute(t_strutt, sostegniTavolino);
	set_attribute(t_ventose, plasticaVentosa);

	// texture mapping
	set_domain_texture(l_strutt, strutturaLampada, "textures/rame02.hr", 0, 1, 0, 1, 0, 0.1, 0.5);
	set_domain_texture(pavimento, moquette, "textures/pavimento.hr", 0, 0.1, 0, 0.1, 1, 0.2, 1);
	set_bump_texture(l_valvolaf, plasticaLampada, "textures/valvolaFacciata1.hr", 0, 1, 0, 1, 0, 0.1, 1);


	// scene creating and saving
	scene = create_list(l_plastica, "scene");
	scene = insert_in_list(scene, l_valvolaf);
	scene = insert_in_list(scene, l_strutt);
	scene = insert_in_list(scene, t_lastre);
	scene = insert_in_list(scene, t_ornamenti);
	scene = insert_in_list(scene, t_strutt);
	scene = insert_in_list(scene, t_ventose);
	scene = insert_in_list(scene, pavimento);
	if(dayoption) save_scene("LampadasuTavolino_day.md", "LampadasuTavolino", scene);
	else save_scene("LampadasuTavolino_night.md", "LampadasuTavolino", scene);
	return(0);

}
